CertificateCompressionAlgorithm

Struct CertificateCompressionAlgorithm 

pub struct CertificateCompressionAlgorithm(pub u16);
The “TLS Certificate Compression Algorithm IDs” TLS protocol enum. Values in this enum are taken from RFC8879.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: CertificateCompressionAlgorithm = CertificateCompressionAlgorithm(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u16

Implementations

Source

impl CertificateCompressionAlgorithm

pub const Zlib: Self

pub const Brotli: Self

pub const Zstd: Self

pub fn to_array(self) -> [u8; 2]

Encode the value as a big-endian byte array.