pub struct EchClientHelloType(pub u8);Expand description
The type of Encrypted Client Hello (EchClientHelloType).
Specified in RFC 9849 Section 5.
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: EchClientHelloType = EchClientHelloType(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u8Implementations
Sourceimpl EchClientHelloType
impl EchClientHelloType
pub const ClientHelloOuter: Self
pub const ClientHelloInner: Self