ProtocolVersion

Struct ProtocolVersion 

pub struct ProtocolVersion(pub u16);
The ProtocolVersion TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: ProtocolVersion = ProtocolVersion(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u16

Implementations

Source

impl ProtocolVersion

pub const SSLv2: Self

pub const SSLv3: Self

pub const TLSv1_0: Self

pub const TLSv1_1: Self

pub const TLSv1_2: Self

pub const TLSv1_3: Self

pub const DTLSv1_0: Self

pub const DTLSv1_2: Self

pub const DTLSv1_3: Self

pub fn to_array(self) -> [u8; 2]

Encode the value as a big-endian byte array.