pub struct HandshakeType(pub u8);Expand description
The HandshakeType TLS protocol enum. Values in this enum are taken
from the various RFCs covering TLS, and are listed by IANA.
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: HandshakeType = HandshakeType(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u8Implementations
Sourceimpl HandshakeType
impl HandshakeType
pub const HelloRequest: Self
pub const ClientHello: Self
pub const ServerHello: Self
pub const HelloVerifyRequest: Self
pub const NewSessionTicket: Self
pub const EndOfEarlyData: Self
pub const HelloRetryRequest: Self
pub const EncryptedExtensions: Self
pub const Certificate: Self
pub const ServerKeyExchange: Self
pub const CertificateRequest: Self
pub const ServerHelloDone: Self
pub const CertificateVerify: Self
pub const ClientKeyExchange: Self
pub const Finished: Self
pub const CertificateURL: Self
pub const CertificateStatus: Self
pub const KeyUpdate: Self
pub const CompressedCertificate: Self
pub const MessageHash: Self