pub struct ProtocolVersion(pub u16);Expand description
The ProtocolVersion TLS protocol enum. Values in this enum are taken
from the various RFCs covering TLS, and are listed by IANA.
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: ProtocolVersion = ProtocolVersion(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u16Implementations